@@ -236,9 +236,9 @@ class DataDisk(DataBase):
     def do_post_loading(self):
         """Apply post loading functions."""
         var_loaded = self.loaded.var[:]
-        for po in self.post_loading_funcs:
-            if po.is_to_launch(var_loaded):
-                po.launch(self)
+        for plf in self.post_loading_funcs:
+            if plf.is_to_launch(var_loaded):
+                plf.launch(self, var_loaded)
 
     def write(self, filename: str, directory: str = None,
               file_kw: Dict = None, var_kw: Dict[str, Dict] = None,
@@ -316,7 +316,6 @@ class DataDisk(DataBase):
         """
         if not self.filegroups:
             raise IndexError("No filegroups in database.")
-        self.check_regex()
         self.check_scanning_functions()
         for fg in self.filegroups:
             fg.scan_files()
@@ -451,15 +450,6 @@ class DataDisk(DataBase):
                 raise ValueError("Duplicate values in filegroups {} and {}"
                                  .format(fg1.name, fg2.name))
 
-    def check_regex(self):
-        """Check if a pregex has been added where needed.
-
-        :raises AttributeError: If regex is empty and there is no file_override.
-        """
-        for fg in self.filegroups:
-            if fg.regex == '' and fg.file_override == '':
-                raise AttributeError(f"Filegroup '{fg.name}' is missing a regex.")
-
     def check_scanning_functions(self):
         """Check if CoordScan have scanning functions set.
 
